@@ -1,16 +1,29 @@
 #include "tree.h"
 
-Tree::Tree (Dataset* train_set, TargetData* targdata, MetaData* meta_data, unsigned seed, vector<int>* pbagging_vec, vector<int>* poob_vec) {
+Tree::Tree (Dataset* train_set,
+        TargetData* targdata,
+        MetaData* meta_data,
+        int min_node_size,
+        unsigned seed,
+        vector<int>* pbagging_vec,
+        vector<int>* poob_vec,
+        int mtry,
+        bool isweight,
+        bool isimportance) {
 
-    train_set_    = train_set;
-    targ_data_    = targdata;
-    meta_data_    = meta_data;
-    seed_         = seed;
-    pbagging_vec_ = pbagging_vec;
-    poob_vec_     = poob_vec;
-    nnodes_       = 0;
-    node_id_      = 0;
-    root_         = NULL;
+    train_set_     = train_set;
+    targ_data_     = targdata;
+    meta_data_     = meta_data;
+    min_node_size_ = min_node_size;
+    seed_          = seed;
+    pbagging_vec_  = pbagging_vec;
+    poob_vec_      = poob_vec;
+    nnodes_        = 0;
+    node_id_       = 0;
+    root_          = NULL;
+    mtry_          = mtry;
+    isweight_      = isweight;
+    isimportance_  = isimportance;
 
     tree_oob_error_rate_  = NA_REAL;
     label_oob_error_rate_ = vector<double>(meta_data->nlabels(), 0);
@@ -19,13 +32,13 @@ Tree::Tree (Dataset* train_set, TargetData* targdata, MetaData* meta_data, unsig
     resetPerm(true);
 }
 
-Tree::Tree (const vector<vector<double> >& node_infos, MetaData* meta_data, double tree_oob_error_rate) {
-    /*
-     * Reconstruct the tree from <node_infos>.
-     *
-     * See Tree::save() for details.
-     */
-
+Tree::Tree (const vector<vector<double> >& node_infos, MetaData* meta_data, double tree_oob_error_rate)
+/*
+ * Reconstruct the tree from <node_infos>.
+ *
+ * See Tree::save() for details.
+ */
+{
     train_set_    = NULL;
     targ_data_    = NULL;
     meta_data_    = meta_data;
@@ -54,31 +67,24 @@ Tree::Tree (const vector<vector<double> >& node_infos, MetaData* meta_data, doub
     resetPerm(true);
 }
 
-void Tree::genBaggingSets () {
+void Tree::genBaggingSets ()
+/*
+ * Sample the observations with replacement.
+ * Generate bagging data set and out-of-bag data set.
+ */
+{
 
     //TODO: If possible, make similar RNG codes into a single function.
 
     int nobs = train_set_->nobs();
     vector<bool> selected_status(nobs, false);
 
-#if defined WSRF_USE_BOOST || defined WSRF_USE_C11
-#ifdef WSRF_USE_BOOST
-    boost::random::uniform_int_distribution<int> uid(0, nobs - 1);
-    boost::random::mt19937 re (seed_);
-#else
     uniform_int_distribution<int> uid {0, nobs - 1};
     default_random_engine re {seed_};
-#endif
-#else
-    Rcpp::RNGScope rngScope;
-#endif
 
     for (int j = 0; j < nobs; ++j) {
-#if defined WSRF_USE_BOOST || defined WSRF_USE_C11
         int random_num = uid(re);
-#else
-        int random_num = unif_rand() * nobs;
-#endif
+
         (*pbagging_vec_)[j] = random_num;
         selected_status[random_num] = true;
     }
@@ -91,25 +97,26 @@ void Tree::genBaggingSets () {
     oob_predict_label_set_ = vector<int>(poob_vec_->size());
 }
 
-void Tree::build (int nvars, bool withweights, bool importance, volatile bool* pinterrupt) {
+void Tree::build (volatile bool* pinterrupt)
+/*
+ * Grow a tree.
+ */
+{
     genBaggingSets();
-    root_ = genC4p5Tree(*pbagging_vec_, meta_data_->getFeatureVars(), nvars, withweights, pinterrupt);
-    calcOOBMeasures(importance);
+    root_ = genC4p5Tree(*pbagging_vec_, meta_data_->getFeatureVars(), pinterrupt);
+    calcOOBMeasures(isimportance_);
 }
 
-Node* Tree::genC4p5Tree (const vector<int>& obs_vec, const vector<int>& var_vec, int nvars, bool isWeighted, volatile bool* pInterrupt) {
-    /*
-     * Build a tree recursively.
-     */
+Node* Tree::genC4p5Tree (const vector<int>& obs_vec, const vector<int>& var_vec, volatile bool* pInterrupt)
+/*
+ * Build a tree recursively.
+ */
+{
+
 
-#if defined WSRF_USE_BOOST || defined WSRF_USE_C11
     if (*pInterrupt) {
         return NULL;
     }
-#else
-    // check interruption
-    if (check_interrupt()) throw interrupt_exception("The random forest model building is interrupted.");
-#endif
 
     int nobs = obs_vec.size();
     if (targ_data_->haveSameLabel(obs_vec)) {
@@ -122,14 +129,16 @@ Node* Tree::genC4p5Tree (const vector<int>& obs_vec, const vector<int>& var_vec,
 
     } else {
         VarSelectRes result;
-        if (isWeighted) {
-            C4p5Selector method(train_set_, targ_data_, meta_data_, obs_vec, var_vec, seed_++);
-            method.doIGRSelection(nvars, result, pInterrupt);
+        if (isweight_) {
+            C4p5Selector method(train_set_, targ_data_, meta_data_, min_node_size_, obs_vec, var_vec, mtry_, seed_);
+            method.doIGRSelection(result, pInterrupt);
         } else {
-            C4p5Selector method(train_set_, targ_data_, meta_data_, obs_vec, var_vec, seed_++);
-            method.doSelection(nvars, result, pInterrupt);
+            C4p5Selector method(train_set_, targ_data_, meta_data_, min_node_size_, obs_vec, var_vec, mtry_, seed_);
+            method.doSelection(result, pInterrupt);
         }
 
+        seed_ += 1;  // Change seed.
+
         if (!result.ok_) {
             // If no better attribute selected
             return createLeafNode(obs_vec, nobs, false);
@@ -145,14 +154,14 @@ Node* Tree::genC4p5Tree (const vector<int>& obs_vec, const vector<int>& var_vec,
                         // Use parent node statistics
                         node->setChild(iter->first, createLeafNode(obs_vec, 0, false));
                     } else {
-                        node->setChild(iter->first, genC4p5Tree(iter->second, new_var_vec, nvars, isWeighted, pInterrupt));
+                        node->setChild(iter->first, genC4p5Tree(iter->second, new_var_vec, pInterrupt));
                     }
                 }
             } else {
                 node = createInternalNode(nobs, result);
                 node->setSplitValue(result.split_value_);
                 for (map<int, vector<int> >::iterator iter = result.split_map_.begin(); iter != result.split_map_.end(); ++iter)
-                    node->setChild(iter->first, genC4p5Tree(iter->second, var_vec, nvars, isWeighted, pInterrupt));
+                    node->setChild(iter->first, genC4p5Tree(iter->second, var_vec, pInterrupt));
             }
 
             return node;
@@ -161,10 +170,11 @@ Node* Tree::genC4p5Tree (const vector<int>& obs_vec, const vector<int>& var_vec,
 }
 
 template<class T>
-void Tree::copyPermData () {
-    /*
-     * Copy data from training set to prepare for permutation.
-     */
+void Tree::copyPermData ()
+/*
+ * Copy data from training set to perm_var_data_, to prepare for permutation.
+ */
+{
 
     //TODO: Need better way to deal with different type of variable, that is DISCRETE, INTSXP, REALSXP.
 
@@ -173,11 +183,11 @@ void Tree::copyPermData () {
     copy(var_array, var_array + train_set_->nobs(), perm_var_data_.begin());
 }
 
-void Tree::permute (int index) {
-    /*
-     * Permute the values of variable <index> for preparation of assessing variable importance.
-     */
-
+void Tree::permute (int index)
+/*
+ * Permute the values of variable <index> for preparation of assessing variable importance.
+ */
+{
     perm_var_idx_ = index;
 
     switch (meta_data_->getVarType(perm_var_idx_)) {
@@ -194,28 +204,12 @@ void Tree::permute (int index) {
 
     //TODO: If possible, make similar RNG codes into a single function.
 
-#if defined WSRF_USE_BOOST || defined WSRF_USE_C11
-#ifdef WSRF_USE_BOOST
-    boost::random::mt19937 re(seed_);
-#else
     default_random_engine re {seed_};
-#endif
-#else
-    Rcpp::RNGScope rngScope;
-#endif
 
     for (int i = train_set_->nobs()-1; i > 0; --i) {
 
-#if defined WSRF_USE_BOOST || defined WSRF_USE_C11
-#ifdef WSRF_USE_BOOST
-        boost::random::uniform_int_distribution<int> uid(0, i);
-#else
         uniform_int_distribution<int> uid {0, i};
-#endif
         int random_num = uid(re);
-#else
-        int random_num = unif_rand() * (i+1);
-#endif
 
         swap(perm_var_data_[i], perm_var_data_[random_num]);
 
@@ -230,11 +224,11 @@ void Tree::resetPerm (bool initial) {
     }
 }
 
-void Tree::calcOOBMeasures (bool importance) {
-    /*
-     * return error rate for classifying training set
-     */
-
+void Tree::calcOOBMeasures (bool importance)
+/*
+ * return error rate for classifying training set
+ */
+{
     // TODO: Extract a method for OOB error rate.
 
     int error_oob = 0;
@@ -274,13 +268,17 @@ void Tree::calcOOBMeasures (bool importance) {
         for (int i = 0, row = 0; i < nlabels+1; row += nvars, i++)
             row_indexes[i] = row;
 
-        // Find used variables.
-        dosthOnNodes(root_, &Tree::markOneVarUsed);
+        // Find used variables and mark in perm_is_var_used_.
+        doSthOnNodes(root_, &Tree::markOneVarUsed);
 
-        // Calculate percent increase in mis-classification rate.
+        /*
+         * Calculate percent increase in mis-classification rate.
+         * TODO: Here we permute only once for each variable used for node splitting.
+         *       We may let the user to specify the number of times for permutation.
+         */
         for (int var_idx = 0; var_idx < nvars; var_idx++) {
             if (perm_is_var_used_[var_idx]) {
-                int error_oob = 0;
+                int total_error_oob = 0;
                 permute(var_idx);
                 for (int i = 0; i < nobs_oob; i++) {
                     int index = (*poob_vec_)[i];
@@ -288,13 +286,15 @@ void Tree::calcOOBMeasures (bool importance) {
                     int actual_label  = targ_data_->getLabel(index) - 1;
 
                     if (predict_label != actual_label) {
-                        error_oob++;
+                        total_error_oob++;
                         tree_perm_VIs_[row_indexes[actual_label] + var_idx]++;
                     }
                 }
 
-                tree_perm_VIs_[row_indexes[nlabels] + var_idx] = error_oob / (double) nobs_oob - tree_oob_error_rate_;
+                // Percent increase in total out-of-bag error rate after permutation.
+                tree_perm_VIs_[row_indexes[nlabels] + var_idx] = total_error_oob / (double) nobs_oob - tree_oob_error_rate_;
 
+                // Percent increase in each label out-of-bag error rate after permutation.
                 for (int i = 0; i < nlabels; i++)
                     tree_perm_VIs_[row_indexes[i] + var_idx] = tree_perm_VIs_[row_indexes[i] + var_idx] / labelcounts[i] - label_oob_error_rate_[i];
             }
@@ -342,16 +342,16 @@ void Tree::print () {
     Rprintf("\n");
 }
 
-void Tree::save (vector<vector<double> >& res) {
-    /*
-     * Store the tree.
-     *
-     * A node is saved as vector<double>,
-     * so the tree is saved as vector<vector<double>>, in breadth-first order and from left to right.
-     */
-
+void Tree::save (vector<vector<double> >& res)
+/*
+ * Store the tree.
+ *
+ * A node is saved as vector<double>,
+ * so the tree is saved as vector<vector<double>>, in breadth-first order and from left to right.
+ */
+{
     tree_ = vector<vector<double> >(nnodes_);
-    dosthOnNodes(root_, &Tree::saveOneNode);
+    doSthOnNodes(root_, &Tree::saveOneNode);
     res.swap(tree_);
 
 }
