@@ -7,6 +7,7 @@
 #include <vector>
 #include <cmath>
 #include <Rcpp.h>
+#include <random>
 
 using namespace std;
 
@@ -59,7 +60,7 @@ const double LN_2 = log((double)2);
 
 
 // wsrf$
-const int WSRF_MODEL_SIZE          = 18;
+const int WSRF_MODEL_SIZE          = 19;
 
 const int META_IDX                 = 0;
 const int TARGET_DATA_IDX          = 1;
@@ -79,6 +80,7 @@ const int CORRELATION_IDX          = 14;
 const int C_S2_IDX                 = 15;
 const int WEIGHTS_IDX              = 16;
 const int MTRY_IDX                 = 17;
+const int NODESIZE_IDX             = 18;
 
 // targetData$
 const string TRAIN_TARGET_LABELS  = "trainTargLabels";
@@ -86,8 +88,6 @@ const string NLABELS              = "nlabels";
 
 // meta$
 const string NVARS                = "nvars";
-const string TARG_IDX             = "targidx";
-const string TARG_NAME            = "targname";
 const string VAR_NAMES            = "varnames";
 const string VAR_TYPES            = "vartypes";
 const string VAL_NAMES            = "valnames";
